==> gossiplog-0.10.0.tgz: package/lib/protocols/events.js <==
/* eslint-disable import/export */
/* eslint-disable complexity */
/* eslint-disable @typescript-eslint/no-namespace */
/* eslint-disable @typescript-eslint/no-unnecessary-boolean-literal-compare */
/* eslint-disable @typescript-eslint/no-empty-interface */
import { CodeError, decodeMessage, encodeMessage, message } from 'protons-runtime';
import { alloc as uint8ArrayAlloc } from 'uint8arrays/alloc';
export var Event;
(function (Event) {
    let Insert;
    (function (Insert) {
        let _codec;
        Insert.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if ((obj.key != null && obj.key.byteLength > 0)) {
                        w.uint32(10);
                        w.bytes(obj.key);
                    }
                    if ((obj.value != null && obj.value.byteLength > 0)) {
                        w.uint32(18);
                        w.bytes(obj.value);
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {
                        key: uint8ArrayAlloc(0),
                        value: uint8ArrayAlloc(0)
                    };
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                obj.key = reader.bytes();
                                break;
                            }
                            case 2: {
                                obj.value = reader.bytes();
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        Insert.encode = (obj) => {
            return encodeMessage(obj, Insert.codec());
        };
        Insert.decode = (buf, opts) => {
            return decodeMessage(buf, Insert.codec(), opts);
        };
    })(Insert = Event.Insert || (Event.Insert = {}));
    let Update;
    (function (Update) {
        let _codec;
        Update.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if (obj.heads != null) {
                        for (const value of obj.heads) {
                            w.uint32(10);
                            w.bytes(value);
                        }
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {
                        heads: []
                    };
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                if (opts.limits?.heads != null && obj.heads.length === opts.limits.heads) {
                                    throw new CodeError('decode error - map field "heads" had too many elements', 'ERR_MAX_LENGTH');
                                }
                                obj.heads.push(reader.bytes());
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        Update.encode = (obj) => {
            return encodeMessage(obj, Update.codec());
        };
        Update.decode = (buf, opts) => {
            return decodeMessage(buf, Update.codec(), opts);
        };
    })(Update = Event.Update || (Event.Update = {}));
    let _codec;
    Event.codec = () => {
        if (_codec == null) {
            _codec = message((obj, w, opts = {}) => {
                if (opts.lengthDelimited !== false) {
                    w.fork();
                }
                if (obj.insert != null) {
                    w.uint32(10);
                    Event.Insert.codec().encode(obj.insert, w);
                }
                if (obj.update != null) {
                    w.uint32(18);
                    Event.Update.codec().encode(obj.update, w);
                }
                if (opts.lengthDelimited !== false) {
                    w.ldelim();
                }
            }, (reader, length, opts = {}) => {
                const obj = {};
                const end = length == null ? reader.len : reader.pos + length;
                while (reader.pos < end) {
                    const tag = reader.uint32();
                    switch (tag >>> 3) {
                        case 1: {
                            obj.insert = Event.Insert.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.insert
                            });
                            break;
                        }
                        case 2: {
                            obj.update = Event.Update.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.update
                            });
                            break;
                        }
                        default: {
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                }
                return obj;
            });
        }
        return _codec;
    };
    Event.encode = (obj) => {
        return encodeMessage(obj, Event.codec());
    };
    Event.decode = (buf, opts) => {
        return decodeMessage(buf, Event.codec(), opts);
    };
})(Event || (Event = {}));

==> gossiplog-0.12.3.tgz: package/lib/protocols/events.js <==
/* eslint-disable import/export */
/* eslint-disable complexity */
/* eslint-disable @typescript-eslint/no-namespace */
/* eslint-disable @typescript-eslint/no-unnecessary-boolean-literal-compare */
/* eslint-disable @typescript-eslint/no-empty-interface */
import { decodeMessage, encodeMessage, MaxLengthError, message } from 'protons-runtime';
import { alloc as uint8ArrayAlloc } from 'uint8arrays/alloc';
export var Event;
(function (Event) {
    let Insert;
    (function (Insert) {
        let _codec;
        Insert.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if ((obj.key != null && obj.key.byteLength > 0)) {
                        w.uint32(10);
                        w.bytes(obj.key);
                    }
                    if ((obj.value != null && obj.value.byteLength > 0)) {
                        w.uint32(18);
                        w.bytes(obj.value);
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {
                        key: uint8ArrayAlloc(0),
                        value: uint8ArrayAlloc(0)
                    };
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                obj.key = reader.bytes();
                                break;
                            }
                            case 2: {
                                obj.value = reader.bytes();
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        Insert.encode = (obj) => {
            return encodeMessage(obj, Insert.codec());
        };
        Insert.decode = (buf, opts) => {
            return decodeMessage(buf, Insert.codec(), opts);
        };
    })(Insert = Event.Insert || (Event.Insert = {}));
    let Update;
    (function (Update) {
        let _codec;
        Update.codec = () => {
            if (_codec == null) {
                _codec = message((obj, w, opts = {}) => {
                    if (opts.lengthDelimited !== false) {
                        w.fork();
                    }
                    if (obj.heads != null) {
                        for (const value of obj.heads) {
                            w.uint32(10);
                            w.bytes(value);
                        }
                    }
                    if (opts.lengthDelimited !== false) {
                        w.ldelim();
                    }
                }, (reader, length, opts = {}) => {
                    const obj = {
                        heads: []
                    };
                    const end = length == null ? reader.len : reader.pos + length;
                    while (reader.pos < end) {
                        const tag = reader.uint32();
                        switch (tag >>> 3) {
                            case 1: {
                                if (opts.limits?.heads != null && obj.heads.length === opts.limits.heads) {
                                    throw new MaxLengthError('Decode error - map field "heads" had too many elements');
                                }
                                obj.heads.push(reader.bytes());
                                break;
                            }
                            default: {
                                reader.skipType(tag & 7);
                                break;
                            }
                        }
                    }
                    return obj;
                });
            }
            return _codec;
        };
        Update.encode = (obj) => {
            return encodeMessage(obj, Update.codec());
        };
        Update.decode = (buf, opts) => {
            return decodeMessage(buf, Update.codec(), opts);
        };
    })(Update = Event.Update || (Event.Update = {}));
    let _codec;
    Event.codec = () => {
        if (_codec == null) {
            _codec = message((obj, w, opts = {}) => {
                if (opts.lengthDelimited !== false) {
                    w.fork();
                }
                if (obj.insert != null) {
                    w.uint32(10);
                    Event.Insert.codec().encode(obj.insert, w);
                }
                if (obj.update != null) {
                    w.uint32(18);
                    Event.Update.codec().encode(obj.update, w);
                }
                if (opts.lengthDelimited !== false) {
                    w.ldelim();
                }
            }, (reader, length, opts = {}) => {
                const obj = {};
                const end = length == null ? reader.len : reader.pos + length;
                while (reader.pos < end) {
                    const tag = reader.uint32();
                    switch (tag >>> 3) {
                        case 1: {
                            obj.insert = Event.Insert.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.insert
                            });
                            break;
                        }
                        case 2: {
                            obj.update = Event.Update.codec().decode(reader, reader.uint32(), {
                                limits: opts.limits?.update
                            });
                            break;
                        }
                        default: {
                            reader.skipType(tag & 7);
                            break;
                        }
                    }
                }
                return obj;
            });
        }
        return _codec;
    };
    Event.encode = (obj) => {
        return encodeMessage(obj, Event.codec());
    };
    Event.decode = (buf, opts) => {
        return decodeMessage(buf, Event.codec(), opts);
    };
})(Event || (Event = {}));
